import Vue from 'vue';
import Vuex from 'vuex';
import getters from './getters';

Vue.use(Vuex);

const modulesFiles = require.context('./modules', true, /\.js$/);

// you do not need `import app from './modules/app'`
// it will auto require all vuex module from modules file
const modules = modulesFiles.keys().reduce((modules, modulePath) => {
    // set './app.js' => 'app'
    const moduleName = modulePath.replace(/^\.\/(.*)\.\w+$/, '$1');
    const value = modulesFiles(modulePath);
    modules[moduleName] = value.default;
    return modules;
}, {});

const store = new Vuex.Store({
    state: {
        modelType: false, //true为PC端，false为手机端
        navSum: sessionStorage.getItem('navPageSize') || 8, // 导航栏显示的条目数量
    },
    mutations: {
        // 根据屏幕尺寸分别移动或者pc
        updateModelType(state, type) {
            console.log(state)
            state.modelType = type;
        },
        // 根据屏幕尺寸显示的导航栏条数
        updateNavSum(state,num) {
            state.navSum = num
        }
    },
    actions: {
        updateNavSumA({ commit },data) {
            commit('updateNavSum',data)
        }
    },
    modules,
    getters
});

export default store;
